@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkRenderer extends vtkViewport
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -495,169 +495,185 @@ public class vtkRenderer extends vtkViewport
   public void UseDepthPeelingOff()
     { UseDepthPeelingOff_110(); }
 
-  private native void SetOcclusionRatio_111(double id0);
+  private native void SetUseDepthPeelingForVolumes_111(boolean id0);
+  public void SetUseDepthPeelingForVolumes(boolean id0)
+    { SetUseDepthPeelingForVolumes_111(id0); }
+
+  private native boolean GetUseDepthPeelingForVolumes_112();
+  public boolean GetUseDepthPeelingForVolumes()
+    { return GetUseDepthPeelingForVolumes_112(); }
+
+  private native void UseDepthPeelingForVolumesOn_113();
+  public void UseDepthPeelingForVolumesOn()
+    { UseDepthPeelingForVolumesOn_113(); }
+
+  private native void UseDepthPeelingForVolumesOff_114();
+  public void UseDepthPeelingForVolumesOff()
+    { UseDepthPeelingForVolumesOff_114(); }
+
+  private native void SetOcclusionRatio_115(double id0);
   public void SetOcclusionRatio(double id0)
-    { SetOcclusionRatio_111(id0); }
+    { SetOcclusionRatio_115(id0); }
 
-  private native double GetOcclusionRatioMinValue_112();
+  private native double GetOcclusionRatioMinValue_116();
   public double GetOcclusionRatioMinValue()
-    { return GetOcclusionRatioMinValue_112(); }
+    { return GetOcclusionRatioMinValue_116(); }
 
-  private native double GetOcclusionRatioMaxValue_113();
+  private native double GetOcclusionRatioMaxValue_117();
   public double GetOcclusionRatioMaxValue()
-    { return GetOcclusionRatioMaxValue_113(); }
+    { return GetOcclusionRatioMaxValue_117(); }
 
-  private native double GetOcclusionRatio_114();
+  private native double GetOcclusionRatio_118();
   public double GetOcclusionRatio()
-    { return GetOcclusionRatio_114(); }
+    { return GetOcclusionRatio_118(); }
 
-  private native void SetMaximumNumberOfPeels_115(int id0);
+  private native void SetMaximumNumberOfPeels_119(int id0);
   public void SetMaximumNumberOfPeels(int id0)
-    { SetMaximumNumberOfPeels_115(id0); }
+    { SetMaximumNumberOfPeels_119(id0); }
 
-  private native int GetMaximumNumberOfPeels_116();
+  private native int GetMaximumNumberOfPeels_120();
   public int GetMaximumNumberOfPeels()
-    { return GetMaximumNumberOfPeels_116(); }
+    { return GetMaximumNumberOfPeels_120(); }
 
-  private native int GetLastRenderingUsedDepthPeeling_117();
+  private native int GetLastRenderingUsedDepthPeeling_121();
   public int GetLastRenderingUsedDepthPeeling()
-    { return GetLastRenderingUsedDepthPeeling_117(); }
+    { return GetLastRenderingUsedDepthPeeling_121(); }
 
-  private native void SetDelegate_118(vtkRendererDelegate id0);
+  private native void SetDelegate_122(vtkRendererDelegate id0);
   public void SetDelegate(vtkRendererDelegate id0)
-    { SetDelegate_118(id0); }
+    { SetDelegate_122(id0); }
 
-  private native long GetDelegate_119();
+  private native long GetDelegate_123();
   public vtkRendererDelegate GetDelegate() {
-    long temp = GetDelegate_119();
+    long temp = GetDelegate_123();
 
     if (temp == 0) return null;
     return (vtkRendererDelegate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetSelector_120();
+  private native long GetSelector_124();
   public vtkHardwareSelector GetSelector() {
-    long temp = GetSelector_120();
+    long temp = GetSelector_124();
 
     if (temp == 0) return null;
     return (vtkHardwareSelector)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetBackgroundTexture_121(vtkTexture id0);
+  private native void SetBackgroundTexture_125(vtkTexture id0);
   public void SetBackgroundTexture(vtkTexture id0)
-    { SetBackgroundTexture_121(id0); }
+    { SetBackgroundTexture_125(id0); }
 
-  private native long GetBackgroundTexture_122();
+  private native long GetBackgroundTexture_126();
   public vtkTexture GetBackgroundTexture() {
-    long temp = GetBackgroundTexture_122();
+    long temp = GetBackgroundTexture_126();
 
     if (temp == 0) return null;
     return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetTexturedBackground_123(boolean id0);
+  private native void SetTexturedBackground_127(boolean id0);
   public void SetTexturedBackground(boolean id0)
-    { SetTexturedBackground_123(id0); }
+    { SetTexturedBackground_127(id0); }
 
-  private native boolean GetTexturedBackground_124();
+  private native boolean GetTexturedBackground_128();
   public boolean GetTexturedBackground()
-    { return GetTexturedBackground_124(); }
+    { return GetTexturedBackground_128(); }
 
-  private native void TexturedBackgroundOn_125();
+  private native void TexturedBackgroundOn_129();
   public void TexturedBackgroundOn()
-    { TexturedBackgroundOn_125(); }
+    { TexturedBackgroundOn_129(); }
 
-  private native void TexturedBackgroundOff_126();
+  private native void TexturedBackgroundOff_130();
   public void TexturedBackgroundOff()
-    { TexturedBackgroundOff_126(); }
+    { TexturedBackgroundOff_130(); }
 
-  private native void ReleaseGraphicsResources_127(vtkWindow id0);
+  private native void ReleaseGraphicsResources_131(vtkWindow id0);
   public void ReleaseGraphicsResources(vtkWindow id0)
-    { ReleaseGraphicsResources_127(id0); }
+    { ReleaseGraphicsResources_131(id0); }
 
-  private native void SetUseFXAA_128(boolean id0);
+  private native void SetUseFXAA_132(boolean id0);
   public void SetUseFXAA(boolean id0)
-    { SetUseFXAA_128(id0); }
+    { SetUseFXAA_132(id0); }
 
-  private native boolean GetUseFXAA_129();
+  private native boolean GetUseFXAA_133();
   public boolean GetUseFXAA()
-    { return GetUseFXAA_129(); }
+    { return GetUseFXAA_133(); }
 
-  private native void UseFXAAOn_130();
+  private native void UseFXAAOn_134();
   public void UseFXAAOn()
-    { UseFXAAOn_130(); }
+    { UseFXAAOn_134(); }
 
-  private native void UseFXAAOff_131();
+  private native void UseFXAAOff_135();
   public void UseFXAAOff()
-    { UseFXAAOff_131(); }
+    { UseFXAAOff_135(); }
 
-  private native long GetFXAAOptions_132();
+  private native long GetFXAAOptions_136();
   public vtkFXAAOptions GetFXAAOptions() {
-    long temp = GetFXAAOptions_132();
+    long temp = GetFXAAOptions_136();
 
     if (temp == 0) return null;
     return (vtkFXAAOptions)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetFXAAOptions_133(vtkFXAAOptions id0);
+  private native void SetFXAAOptions_137(vtkFXAAOptions id0);
   public void SetFXAAOptions(vtkFXAAOptions id0)
-    { SetFXAAOptions_133(id0); }
+    { SetFXAAOptions_137(id0); }
 
-  private native void SetUseShadows_134(int id0);
+  private native void SetUseShadows_138(int id0);
   public void SetUseShadows(int id0)
-    { SetUseShadows_134(id0); }
+    { SetUseShadows_138(id0); }
 
-  private native int GetUseShadows_135();
+  private native int GetUseShadows_139();
   public int GetUseShadows()
-    { return GetUseShadows_135(); }
+    { return GetUseShadows_139(); }
 
-  private native void UseShadowsOn_136();
+  private native void UseShadowsOn_140();
   public void UseShadowsOn()
-    { UseShadowsOn_136(); }
+    { UseShadowsOn_140(); }
 
-  private native void UseShadowsOff_137();
+  private native void UseShadowsOff_141();
   public void UseShadowsOff()
-    { UseShadowsOff_137(); }
+    { UseShadowsOff_141(); }
 
-  private native void SetUseHiddenLineRemoval_138(int id0);
+  private native void SetUseHiddenLineRemoval_142(int id0);
   public void SetUseHiddenLineRemoval(int id0)
-    { SetUseHiddenLineRemoval_138(id0); }
+    { SetUseHiddenLineRemoval_142(id0); }
 
-  private native int GetUseHiddenLineRemoval_139();
+  private native int GetUseHiddenLineRemoval_143();
   public int GetUseHiddenLineRemoval()
-    { return GetUseHiddenLineRemoval_139(); }
+    { return GetUseHiddenLineRemoval_143(); }
 
-  private native void UseHiddenLineRemovalOn_140();
+  private native void UseHiddenLineRemovalOn_144();
   public void UseHiddenLineRemovalOn()
-    { UseHiddenLineRemovalOn_140(); }
+    { UseHiddenLineRemovalOn_144(); }
 
-  private native void UseHiddenLineRemovalOff_141();
+  private native void UseHiddenLineRemovalOff_145();
   public void UseHiddenLineRemovalOff()
-    { UseHiddenLineRemovalOff_141(); }
+    { UseHiddenLineRemovalOff_145(); }
 
-  private native void SetPass_142(vtkRenderPass id0);
+  private native void SetPass_146(vtkRenderPass id0);
   public void SetPass(vtkRenderPass id0)
-    { SetPass_142(id0); }
+    { SetPass_146(id0); }
 
-  private native long GetPass_143();
+  private native long GetPass_147();
   public vtkRenderPass GetPass() {
-    long temp = GetPass_143();
+    long temp = GetPass_147();
 
     if (temp == 0) return null;
     return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetInformation_144();
+  private native long GetInformation_148();
   public vtkInformation GetInformation() {
-    long temp = GetInformation_144();
+    long temp = GetInformation_148();
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetInformation_145(vtkInformation id0);
+  private native void SetInformation_149(vtkInformation id0);
   public void SetInformation(vtkInformation id0)
-    { SetInformation_145(id0); }
+    { SetInformation_149(id0); }
 
   public vtkRenderer() { super(); }
 
